==> spip_3.1.4.orig.tar.xz: spip/ecrire/charsets/html.php <==
<?php

/**
 * Déclaration des entités HTML (à completer éventuellement) et leur correspondances
 * en écriture unicode
 *
 * @package SPIP\Core\Charsets
 **/

$GLOBALS['CHARSET']['html'] = array(
	'ldquo' => '&#8220;',
	'rdquo' => '&#8221;',
	'bdquo' => '&#8222;',
	'cent' => '&#162;',
	'pound' => '&#163;',
	'curren' => '&#164;',
	'yen' => '&#165;',
	'brvbar' => '&#166;',
	'sect' => '&#167;',
	'uml' => '&#168;',
	'ordf' => '&#170;',
	'laquo' => '&#171;',
	'lsquo' => '&#8216;',
	'rsquo' => '&#8217;',
	'not' => '&#172;',
	'shy' => '&#173;',
	'macr' => '&#175;',
	'deg' => '&#176;',
	'plusmn' => '&#177;',
	'sup2' => '&#178;',
	'sup3' => '&#179;',
	'acute' => '&#180;',
	'micro' => '&#181;',
	'para' => '&#182;',
	'middot' => '&#183;',
	'cedil' => '&#184;',
	'sup1' => '&#185;',
	'ordm' => '&#186;',
	'raquo' => '&#187;',
	'iquest' => '&#191;',
	'Agrave' => '&#192;',
	'Aacute' => '&#193;',
	'Acirc' => '&#194;',
	'Atilde' => '&#195;',
	'Auml' => '&#196;',
	'Aring' => '&#197;',
	'AElig' => '&#198;',
	'Ccedil' => '&#199;',
	'Egrave' => '&#200;',
	'Eacute' => '&#201;',
	'Ecirc' => '&#202;',
	'Euml' => '&#203;',
	'Igrave' => '&#204;',
	'Iacute' => '&#205;',
	'Icirc' => '&#206;',
	'Iuml' => '&#207;',
	'ETH' => '&#208;',
	'Ntilde' => '&#209;',
	'Ograve' => '&#210;',
	'Oacute' => '&#211;',
	'Ocirc' => '&#212;',
	'Otilde' => '&#213;',
	'Ouml' => '&#214;',
	'times' => '&#215;',
	'Oslash' => '&#216;',
	'Ugrave' => '&#217;',
	'Uacute' => '&#218;',
	'Ucirc' => '&#219;',
	'Uuml' => '&#220;',
	'Yacute' => '&#221;',
	'THORN' => '&#222;',
	'szlig' => '&#223;',
	'agrave' => '&#224;',
	'Scaron' => '&#352;',
	'scaron' => '&#353;',
	'zcaron' => '&#x17E;',
	'Zcaron' => '&#x17D;',
	'aacute' => '&#225;',
	'acirc' => '&#226;',
	'atilde' => '&#227;',
	'auml' => '&#228;',
	'aring' => '&#229;',
	'aelig' => '&#230;',
	'ccedil' => '&#231;',
	'egrave' => '&#232;',
	'eacute' => '&#233;',
	'ecirc' => '&#234;',
	'euml' => '&#235;',
	'igrave' => '&#236;',
	'iacute' => '&#237;',
	'icirc' => '&#238;',
	'iuml' => '&#239;',
	'eth' => '&#240;',
	'ntilde' => '&#241;',
	'ograve' => '&#242;',
	'oacute' => '&#243;',
	'ocirc' => '&#244;',
	'otilde' => '&#245;',
	'ouml' => '&#246;',
	'divide' => '&#247;',
	'oslash' => '&#248;',
	'ugrave' => '&#249;',
	'uacute' => '&#250;',
	'ucirc' => '&#251;',
	'uuml' => '&#252;',
	'yacute' => '&#253;',
	'thorn' => '&#254;',
	'nbsp' => " ",
	'thinsp' => '&#8201;',
	'ensp' => '&#8194;',
	'emsp' => '&#8195;',
	'copy' => "(c)",
	'reg' => "(r)",
	'frac14' => "1/4",
	'frac12' => "1/2",
	'frac34' => "3/4",
	'apos' => "'",
	'mdash' => '&#8212;',
	'ndash' => '&#8211;',
	'hellip' => '&#8230;',
	'euro' => '&#8364;',
	'OElig' => '&#338;',
	'oelig' => '&#339;',
	'iexcl' => '&#161;'

);

## caracteres tres speciaux a ne pas convertir
#'amp' => '&', 'quot' => '"', 'lt' => '<', 'gt' => '>',
;

==> spip_3.2.7.orig.tar.xz: spip/ecrire/charsets/html.php <==
<?php

/**
 * Déclaration des entités HTML (à completer éventuellement) et leur correspondances
 * en écriture unicode
 *
 * @package SPIP\Core\Charsets
 **/

$GLOBALS['CHARSET']['html'] = array(
	'ldquo' => '&#8220;',
	'rdquo' => '&#8221;',
	'bdquo' => '&#8222;',
	'cent' => '&#162;',
	'pound' => '&#163;',
	'curren' => '&#164;',
	'yen' => '&#165;',
	'brvbar' => '&#166;',
	'sect' => '&#167;',
	'uml' => '&#168;',
	'ordf' => '&#170;',
	'laquo' => '&#171;',
	'lsquo' => '&#8216;',
	'rsquo' => '&#8217;',
	'not' => '&#172;',
	'shy' => '&#173;',
	'macr' => '&#175;',
	'deg' => '&#176;',
	'plusmn' => '&#177;',
	'sup2' => '&#178;',
	'sup3' => '&#179;',
	'acute' => '&#180;',
	'micro' => '&#181;',
	'para' => '&#182;',
	'middot' => '&#183;',
	'cedil' => '&#184;',
	'sup1' => '&#185;',
	'ordm' => '&#186;',
	'raquo' => '&#187;',
	'iquest' => '&#191;',
	'Agrave' => '&#192;',
	'Aacute' => '&#193;',
	'Acirc' => '&#194;',
	'Atilde' => '&#195;',
	'Auml' => '&#196;',
	'Aring' => '&#197;',
	'AElig' => '&#198;',
	'Ccedil' => '&#199;',
	'Egrave' => '&#200;',
	'Eacute' => '&#201;',
	'Ecirc' => '&#202;',
	'Euml' => '&#203;',
	'Igrave' => '&#204;',
	'Iacute' => '&#205;',
	'Icirc' => '&#206;',
	'Iuml' => '&#207;',
	'ETH' => '&#208;',
	'Ntilde' => '&#209;',
	'Ograve' => '&#210;',
	'Oacute' => '&#211;',
	'Ocirc' => '&#212;',
	'Otilde' => '&#213;',
	'Ouml' => '&#214;',
	'times' => '&#215;',
	'Oslash' => '&#216;',
	'Ugrave' => '&#217;',
	'Uacute' => '&#218;',
	'Ucirc' => '&#219;',
	'Uuml' => '&#220;',
	'Yacute' => '&#221;',
	'THORN' => '&#222;',
	'szlig' => '&#223;',
	'agrave' => '&#224;',
	'Scaron' => '&#352;',
	'scaron' => '&#353;',
	'zcaron' => '&#x17E;',
	'Zcaron' => '&#x17D;',
	'aacute' => '&#225;',
	'acirc' => '&#226;',
	'atilde' => '&#227;',
	'auml' => '&#228;',
	'aring' => '&#229;',
	'aelig' => '&#230;',
	'ccedil' => '&#231;',
	'egrave' => '&#232;',
	'eacute' => '&#233;',
	'ecirc' => '&#234;',
	'euml' => '&#235;',
	'igrave' => '&#236;',
	'iacute' => '&#237;',
	'icirc' => '&#238;',
	'iuml' => '&#239;',
	'eth' => '&#240;',
	'ntilde' => '&#241;',
	'ograve' => '&#242;',
	'oacute' => '&#243;',
	'ocirc' => '&#244;',
	'otilde' => '&#245;',
	'ouml' => '&#246;',
	'divide' => '&#247;',
	'oslash' => '&#248;',
	'ugrave' => '&#249;',
	'uacute' => '&#250;',
	'ucirc' => '&#251;',
	'uuml' => '&#252;',
	'yacute' => '&#253;',
	'thorn' => '&#254;',
	'nbsp' => ' ',
	'thinsp' => '&#8201;',
	'ensp' => '&#8194;',
	'emsp' => '&#8195;',
	'copy' => '(c)',
	'reg' => '(r)',
	'frac14' => '1/4',
	'frac12' => '1/2',
	'frac34' => '3/4',
	'apos' => "'",
	'mdash' => '&#8212;',
	'ndash' => '&#8211;',
	'hellip' => '&#8230;',
	'euro' => '&#8364;',
	'OElig' => '&#338;',
	'oelig' => '&#339;',
	'iexcl' => '&#161;'

);

## caracteres tres speciaux a ne pas convertir
#'amp' => '&', 'quot' => '"', 'lt' => '<', 'gt' => '>',
;
